@@ -7,10 +7,11 @@ use base 'FusionInventory::Agent::XML::Query';
 sub new {
     my ($class, %params) = @_;
 
-    die "no token parameter" unless $params{token};
+    die "no deviceid parameter" unless $params{deviceid};
 
     return $class->SUPER::new(
         query => 'PROLOG',
+        token => '12345678',
         %params
     );
 
@@ -38,8 +39,4 @@ from the base class C<FusionInventory::Agent::XML::Query>, as keys of the
 
 =over
 
-=item I<token>
-
-the authentication token for the web interface (mandatory)
-
 =back
