@@ -3,7 +3,6 @@ package FusionInventory::Agent::XML::Response;
 use strict;
 use warnings;
 
-use List::Util qw(first);
 use XML::TreePP;
 
 sub new {
@@ -11,7 +10,7 @@ sub new {
 
     my $tpp = XML::TreePP->new(
         force_array   => [ qw/
-            OPTION PARAM MODEL AUTHENTICATION RANGEIP DEVICE
+            OPTION PARAM MODEL AUTHENTICATION RANGEIP DEVICE GET WALK
             / ],
         attr_prefix   => '',
         text_node_key => 'content'
@@ -42,7 +41,7 @@ sub getOptionsInfoByName {
     return unless $self->{content}->{OPTION};
 
     return
-        first { $_->{NAME} eq $name }
+        grep { $_->{NAME} eq $name }
         @{$self->{content}->{OPTION}};
 }
 
